import requests

def text(api, model, prompt):
    url = "https://api.openai.com/v1/chat/completions"

    r = requests.post(
        url,
        headers={
            "Authorization": f"Bearer {api}",
            "Content-Type": "application/json"
        },
        json={
            "model": model,
            "messages": [{"role": "user", "content": prompt}]
        },
)
    data = r.json()
    print(data["choices"][0]["message"]["content"])

def image(api, model, text, size):
    url = "https://api.openai.com/v1/images/generations"
    r = requests.post(
        url,
        headers={
            "Authorization": f"Bearer {api}",
            "Content-Type": "application/json"
        },
        json={
            "model": model,
            "prompt": text,
            "n": 1,
            "size": size
        },
)
    print(r.json()["data"][0]["url"])

def apicheck(api):
    checkurl = "https://api.openai.com/v1/chat/completions"
    check = requests.post(
        checkurl,
        headers={
             "Authorization": f"Bearer {api}",
             "Content-Type": "application/json"
             },
        json={
            "model": "gpt-4o-mini",
            "messages": [{"role": "user", "content": "test"}]
        },
)

    if check.status_code == 200:
        print("gptio | Success / Text Service")
        textworks = True
    else:
        print("gptio | Unsuccess / Text Service")
        textworks = False

    imgcheck = requests.post(
        "https://api.openai.com/v1/images/generations",
        headers={
            "Authorization": f"Bearer {api}",
            "Content-Type": "application/json"
        },
        json={
            "model": "gpt-image-1",
            "prompt": "test",
            "size": "1024x1024"
        }
    )

    if imgcheck.status_code == 200:
        print("gptio | Success / Image Service")
        imgworks = True
    else:
        print("gptio | Unsuccess / Image Service")
        imgworks = False

def send(api, model, text):
    url = "https://api.openai.com/v1/chat/completions"
    r = requests.post(
        url,
        headers={
            "Authorization": f"Bearer {api}",
            "Content-Type": "application/json"
        },
        json={
            "model": model,
            "messages": [{"role": "user", "content": text}]
        },
    )
    datas = r.json()
    return datas["choices"][0]["message"]["content"]


from setuptools import setup

setup(
    name="gptio",               # your module name
    version="0.1.6",
    author="wirnty",
author_email="skedovichusjdj@gmail.com.com",
    description="A simple Python module to interact with ChatGPT via OpenAI API.",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    py_modules=["gptio"],       # <-- points to your single .py file
    python_requires=">=3.12",
    install_requires=[
        "requests>=2.31.0"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries",
        "Intended Audience :: Developers"
    ],
)